#[non_exhaustive]pub enum PromptType {
Question,
Secret,
}Expand description
Prompt types the client is required to display.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Question
prompt is a question. The information can be shown as it is entered.
Secret
prompt is for secret information. The entered information should be obscured so it can’t be publically visible.