GreeterExt

Trait GreeterExt 

pub trait GreeterExt: IsA<Greeter> + 'static {
Show 39 methods // Provided methods fn cancel_autologin(&self) { ... } fn authentication_user(&self) -> Option<GString> { ... } fn is_autologin_guest_hint(&self) -> bool { ... } fn autologin_session_hint(&self) -> Option<GString> { ... } fn autologin_timeout_hint(&self) -> i32 { ... } fn autologin_user_hint(&self) -> Option<GString> { ... } fn default_session_hint(&self) -> Option<GString> { ... } fn has_guest_account_hint(&self) -> bool { ... } fn hides_users_hint(&self) -> bool { ... } fn hint(&self, name: &str) -> Option<GString> { ... } fn is_in_authentication(&self) -> bool { ... } fn is_authenticated(&self) -> bool { ... } fn is_lock_hint(&self) -> bool { ... } fn selects_guest_hint(&self) -> bool { ... } fn select_user_hint(&self) -> Option<GString> { ... } fn shows_manual_login_hint(&self) -> bool { ... } fn shows_remote_login_hint(&self) -> bool { ... } fn set_resettable(&self, resettable: bool) { ... } fn connect_authentication_complete<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_autologin_timer_expired<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_idle<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... } fn connect_reset<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... } fn connect_show_message<F: Fn(&Self, &str, MessageType) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_show_prompt<F: Fn(&Self, &str, PromptType) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_authentication_user_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_autologin_guest_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_autologin_session_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_autologin_timeout_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_autologin_user_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_default_session_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_has_guest_account_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_hide_users_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_in_authentication_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_is_authenticated_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_lock_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_select_guest_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_select_user_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_show_manual_login_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_show_remote_login_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all Greeter methods.

Implementors

Greeter

Provided Methods

fn cancel_autologin(&self)

Cancel the automatic login.

fn authentication_user(&self) -> Option<GString>

Get the user that is being authenticated.

Returns

The username of the authentication user being authenticated or #NULL if no authentication in progress.

fn is_autologin_guest_hint(&self) -> bool

Check if the guest account should be automatically logged into when the timer expires.

Returns

#TRUE if the guest account should be automatically logged into.

fn autologin_session_hint(&self) -> Option<GString>

Get the session used to automatically log into when the timer expires.

Returns

The session name or None if configured to use the default.

fn autologin_timeout_hint(&self) -> i32

Get the number of seconds to wait before automatically logging in.

Returns

The number of seconds to wait before automatically logging in or 0 for no timeout.

fn autologin_user_hint(&self) -> Option<GString>

Get the user account to automatically log into when the timer expires.

Returns

The user account to automatically log into or None if none configured.

fn default_session_hint(&self) -> Option<GString>

Get the default session to use.

Returns

The session name

fn has_guest_account_hint(&self) -> bool

Check if guest sessions are supported.

Returns

#TRUE if guest sessions are supported.

fn hides_users_hint(&self) -> bool

Check if user accounts should be shown. If this is TRUE then the list of accounts should be taken from #LightDMUserList and displayed in the greeter for the user to choose from. Note that this list can be empty and it is recommended you show a method for the user to enter a username manually.

If this option is shown the greeter should only allow these users to be chosen for login unless the manual login hint is set.

Returns

#TRUE if the available users should not be shown.

fn hint(&self, name: &str) -> Option<GString>

Get a hint.

name

The hint name to query.

Returns

The value for this hint or #NULL if not set.

fn is_in_authentication(&self) -> bool

Checks if the greeter is in the process of authenticating.

Returns

#TRUE if the greeter is authenticating a user.

fn is_authenticated(&self) -> bool

Checks if the greeter has successfully authenticated.

Returns

#TRUE if the greeter is authenticated for login.

fn is_lock_hint(&self) -> bool

Check if the greeter is acting as a lock screen.

Returns

#TRUE if the greeter was triggered by locking the seat.

fn selects_guest_hint(&self) -> bool

Check if the guest account should be selected by default.

Returns

#TRUE if the guest account should be selected by default.

fn select_user_hint(&self) -> Option<GString>

Get the user to select by default.

Returns

A username or None if no particular user should be selected.

fn shows_manual_login_hint(&self) -> bool

Check if a manual login option should be shown. If set the GUI should provide a way for a username to be entered manually. Without this hint a greeter which is showing a user list can limit logins to only those users.

Returns

#TRUE if a manual login option should be shown.

fn shows_remote_login_hint(&self) -> bool

Check if a remote login option should be shown. If set the GUI should provide a way for a user to log into a remote desktop server.

Returns

#TRUE if a remote login option should be shown.

fn set_resettable(&self, resettable: bool)

Set whether the greeter will be reset instead of killed after the user logs in. This must be called before lightdm_greeter_connect is called.

resettable

Whether the greeter wants to be reset instead of killed after the user logs in

fn connect_authentication_complete<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

The ::authentication-complete signal gets emitted when the greeter has completed authentication.

Call lightdm_greeter_get_is_authenticated() to check if the authentication was successful.

fn connect_autologin_timer_expired<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

The ::timed-login signal gets emitted when the automatic login timer has expired. The application should then call lightdm_greeter_authenticate_autologin().

fn connect_idle<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The ::idle signal gets emitted when the user has logged in and the greeter is no longer needed.

This signal only matters if the greeter has marked itself as resettable using lightdm_greeter_set_resettable().

fn connect_reset<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The ::reset signal gets emitted when the user is returning to a greeter that was previously marked idle.

This signal only matters if the greeter has marked itself as resettable using lightdm_greeter_set_resettable().

fn connect_show_message<F: Fn(&Self, &str, MessageType) + 'static>( &self, f: F, ) -> SignalHandlerId

The ::show-message signal gets emitted when the greeter should show a message to the user.

text

Message text

type_

Message type

fn connect_show_prompt<F: Fn(&Self, &str, PromptType) + 'static>( &self, f: F, ) -> SignalHandlerId

The ::show-prompt signal gets emitted when the greeter should show a prompt to the user. The given text should be displayed and an input field for the user to provide a response.

Call lightdm_greeter_respond() with the resultant input or lightdm_greeter_cancel_authentication() to abort the authentication.

text

Prompt text

type_

Prompt type

fn connect_authentication_user_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_autologin_guest_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_autologin_session_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_autologin_timeout_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_autologin_user_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_default_session_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_has_guest_account_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_hide_users_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_in_authentication_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_is_authenticated_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_lock_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_select_guest_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_select_user_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_show_manual_login_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_show_remote_login_hint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<O: IsA<Greeter>> GreeterExt for O