UserExt

Trait UserExt 

pub trait UserExt: IsA<User> + 'static {
Show 29 methods // Provided methods fn background(&self) -> Option<GString> { ... } fn display_name(&self) -> Option<GString> { ... } fn has_messages(&self) -> bool { ... } fn home_directory(&self) -> Option<GString> { ... } fn image(&self) -> Option<GString> { ... } fn is_locked(&self) -> bool { ... } fn language(&self) -> Option<GString> { ... } fn layout(&self) -> Option<GString> { ... } fn layouts(&self) -> Vec<GString> { ... } fn is_logged_in(&self) -> bool { ... } fn name(&self) -> Option<GString> { ... } fn real_name(&self) -> Option<GString> { ... } fn session(&self) -> Option<GString> { ... } fn uid(&self) -> u32 { ... } fn connect_changed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... } fn connect_background_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_display_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_has_messages_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_home_directory_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_image_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_is_locked_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_language_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_layout_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_layouts_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_logged_in_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_real_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_session_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_uid_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all User methods.

Implementors

User

Provided Methods

fn background(&self) -> Option<GString>

Get the background file path for a user.

Returns

The background file path for the given user or #NULL if no path

fn display_name(&self) -> Option<GString>

Get the display name of a user.

Returns

The display name of the given user

fn has_messages(&self) -> bool

Check if a user has waiting messages.

Returns

#TRUE if the user has waiting messages.

fn home_directory(&self) -> Option<GString>

Get the home directory for a user.

Returns

The users home directory

fn image(&self) -> Option<GString>

Get the image URI for a user.

Returns

The image URI for the given user or #NULL if no URI

fn is_locked(&self) -> bool

Get if the user is locked.

Returns

true if the user is locked

fn language(&self) -> Option<GString>

Get the language for a user.

Returns

The language in the form of a local specification (e.g. “de_DE.UTF-8”) for the given user or #NULL if using the system default locale.

fn layout(&self) -> Option<GString>

Get the keyboard layout for a user.

Returns

The keyboard layout for the given user or #NULL if using system defaults. Copy the value if you want to use it long term.

fn layouts(&self) -> Vec<GString>

Get the configured keyboard layouts for a user.

Returns

A NULL-terminated array of keyboard layouts for the given user. Copy the values if you want to use them long term.

fn is_logged_in(&self) -> bool

Check if a user is logged in.

Returns

#TRUE if the user is currently logged in.

fn name(&self) -> Option<GString>

Get the name of a user.

Returns

The name of the given user

fn real_name(&self) -> Option<GString>

Get the real name of a user.

Returns

The real name of the given user

fn session(&self) -> Option<GString>

Get the session for a user.

Returns

The session for the given user or #NULL if using system defaults.

fn uid(&self) -> u32

Get the uid of a user.

Returns

The uid of the given user

fn connect_changed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The ::changed signal gets emitted this user account is modified.

fn connect_background_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_display_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_has_messages_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_home_directory_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_image_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_is_locked_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_language_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_layout_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_layouts_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_logged_in_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_name_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_real_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_session_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_uid_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<O: IsA<User>> UserExt for O