Greeter

Struct Greeter 

pub struct Greeter { /* private fields */ }
#LightDMGreeter is an opaque data structure and can only be accessed using the provided functions.

Properties

authentication-user

Readable

autologin-guest-hint

Readable

autologin-session-hint

Readable

autologin-timeout-hint

Readable

autologin-user-hint

Readable

default-session-hint

Readable

has-guest-account-hint

Readable

hide-users-hint

Readable

in-authentication

Readable

is-authenticated

Readable

lock-hint

Readable

select-guest-hint

Readable

select-user-hint

Readable

show-manual-login-hint

Readable

show-remote-login-hint

Readable

Signals

authentication-complete

The ::authentication-complete signal gets emitted when the greeter has completed authentication.

Call lightdm_greeter_get_is_authenticated() to check if the authentication was successful.

autologin-timer-expired

The ::timed-login signal gets emitted when the automatic login timer has expired. The application should then call lightdm_greeter_authenticate_autologin().

idle

The ::idle signal gets emitted when the user has logged in and the greeter is no longer needed.

This signal only matters if the greeter has marked itself as resettable using lightdm_greeter_set_resettable().

reset

The ::reset signal gets emitted when the user is returning to a greeter that was previously marked idle.

This signal only matters if the greeter has marked itself as resettable using lightdm_greeter_set_resettable().

show-message

The ::show-message signal gets emitted when the greeter should show a message to the user.

show-prompt

The ::show-prompt signal gets emitted when the greeter should show a prompt to the user. The given text should be displayed and an input field for the user to provide a response.

Call lightdm_greeter_respond() with the resultant input or lightdm_greeter_cancel_authentication() to abort the authentication.

Implements

GreeterExt, GreeterExtManual

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl Greeter

pub const NONE: Option<&'static Greeter> = None

pub fn new() -> Greeter

Create a new greeter.

Returns

the new #LightDMGreeter