pub trait UserExt: IsA<User> + 'static {
Show 29 methods
// Provided methods
fn background(&self) -> Option<GString> { ... }
fn display_name(&self) -> Option<GString> { ... }
fn has_messages(&self) -> bool { ... }
fn home_directory(&self) -> Option<GString> { ... }
fn image(&self) -> Option<GString> { ... }
fn is_locked(&self) -> bool { ... }
fn language(&self) -> Option<GString> { ... }
fn layout(&self) -> Option<GString> { ... }
fn layouts(&self) -> Vec<GString> { ... }
fn is_logged_in(&self) -> bool { ... }
fn name(&self) -> Option<GString> { ... }
fn real_name(&self) -> Option<GString> { ... }
fn session(&self) -> Option<GString> { ... }
fn uid(&self) -> u32 { ... }
fn connect_changed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn connect_background_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_display_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_has_messages_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_home_directory_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_image_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_is_locked_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_language_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_layout_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_layouts_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_logged_in_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_real_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_session_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_uid_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Provided Methods
Sourcefn background(&self) -> Option<GString>
fn background(&self) -> Option<GString>
Get the background file path for a user.
Returns
The background file path for the given user or #NULL if no path
Sourcefn display_name(&self) -> Option<GString>
fn display_name(&self) -> Option<GString>
Sourcefn has_messages(&self) -> bool
fn has_messages(&self) -> bool
Sourcefn home_directory(&self) -> Option<GString>
fn home_directory(&self) -> Option<GString>
Sourcefn language(&self) -> Option<GString>
fn language(&self) -> Option<GString>
Get the language for a user.
Returns
The language in the form of a local specification (e.g. “de_DE.UTF-8”) for the given user or #NULL if using the system default locale.
Sourcefn layout(&self) -> Option<GString>
fn layout(&self) -> Option<GString>
Get the keyboard layout for a user.
Returns
The keyboard layout for the given user or #NULL if using system defaults. Copy the value if you want to use it long term.
Sourcefn layouts(&self) -> Vec<GString>
fn layouts(&self) -> Vec<GString>
Get the configured keyboard layouts for a user.
Returns
A NULL-terminated array of keyboard layouts for the given user. Copy the values if you want to use them long term.
Sourcefn is_logged_in(&self) -> bool
fn is_logged_in(&self) -> bool
Sourcefn session(&self) -> Option<GString>
fn session(&self) -> Option<GString>
Get the session for a user.
Returns
The session for the given user or #NULL if using system defaults.
Sourcefn connect_changed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_changed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
The ::changed signal gets emitted this user account is modified.
fn connect_background_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_display_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_has_messages_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_home_directory_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_image_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_is_locked_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_language_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_layout_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_layouts_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_logged_in_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_name_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_real_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_session_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_uid_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.